PyXMake Developer Guide: PyXMake.Build.Make.POSIX Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.POSIX Class Reference

Abstract base class for all POSIX subclasses. More...

Inheritance diagram for PyXMake.Build.Make.POSIX:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| __create__ (self, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.OS
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | SystemObjectKind = "POSIX"
| String identifier of current instance.
| scrtdir
| Overwrite create method in all subclasses to use a predefined MakeFile for all builds.
| temps = self.temps + ("Makefile",)
| Overwrite create method in all subclasses to use a predefined MakeFile for all builds.
| environ = copy.deepcopy(getattr(os.environ,"_data",{}))
| precmd = GetPreprocessingCommand(1).split() + self.precmd.split()[4:]; self.precmd.insert(-1,"-o")
str | precmd = ""
| verbose
| intermediate_wrapper
| wrapper_module = self.scrtdir)
| libdirs
| outdir
| Accept both OutLibs and OutDir variable.
| outlibs = self.outmodule:
| outmodule = True)
Public Attributes inherited from PyXMake.Build.Make.OS
str | SystemObjectKind = "Base"
| String identifier of current instance.

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)

## Detailed Description

Abstract base class for all POSIX subclasses.

    Inherited class to POSIX projects without any presets.

Inherited from built-in ABCMeta & object. Compatible with both Python 2.x and 3.x.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.POSIX.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of POSIX class object.

Reimplemented from PyXMake.Build.Make.OS.

Reimplemented in PyXMake.Build.Make.CCxx, PyXMake.Build.Make.Fortran, and PyXMake.Build.Make.Py2X.

Definition at line 139 of file Make.py.

## Member Function Documentation

## ◆ __create__()

PyXMake.Build.Make.POSIX.__create__ | ( |  | self,
|  | ** | kwargs )

    Unified create function replacing all create commands of ALL classes when used with Mingx64 or on Linux. All builds are solely
    defined by one unified Makefile. in these cases.

Definition at line 154 of file Make.py.

## Member Data Documentation

## ◆ environ

PyXMake.Build.Make.POSIX.environ = copy.deepcopy(getattr(os.environ,"_data",{}))

Definition at line 172 of file Make.py.

## ◆ intermediate_wrapper

PyXMake.Build.Make.POSIX.intermediate_wrapper

Definition at line 250 of file Make.py.

## ◆ libdirs

PyXMake.Build.Make.POSIX.libdirs

Definition at line 292 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.POSIX.outdir

Accept both OutLibs and OutDir variable.

Checks for existence of OutLibs first.

Definition at line 429 of file Make.py.

## ◆ outlibs

PyXMake.Build.Make.POSIX.outlibs = self.outmodule:

Definition at line 435 of file Make.py.

## ◆ outmodule

PyXMake.Build.Make.POSIX.outmodule = True)

Definition at line 437 of file Make.py.

## ◆ precmd [1/2]

PyXMake.Build.Make.POSIX.precmd = GetPreprocessingCommand(1).split() + self.precmd.split()[4:]; self.precmd.insert(-1,"-o")

Definition at line 187 of file Make.py.

## ◆ precmd [2/2]

str PyXMake.Build.Make.POSIX.precmd = ""

Definition at line 192 of file Make.py.

## ◆ scrtdir

PyXMake.Build.Make.POSIX.scrtdir

Overwrite create method in all subclasses to use a predefined MakeFile for all builds.

This implements the use of gcc, g++ and gfortran as well as Mingw64 and Linux shell support. Convoluted, but working.

Definition at line 150 of file Make.py.

## ◆ SystemObjectKind

str PyXMake.Build.Make.POSIX.SystemObjectKind = "POSIX"

String identifier of current instance.

Definition at line 145 of file Make.py.

## ◆ temps

PyXMake.Build.Make.POSIX.temps = self.temps + ("Makefile",)

Overwrite create method in all subclasses to use a predefined MakeFile for all builds.

This implements the use of gcc, g++ and gfortran as well as Mingw64 and Linux shell support. Convoluted, but working.

Definition at line 152 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.POSIX.verbose

Definition at line 242 of file Make.py.

## ◆ wrapper_module

PyXMake.Build.Make.POSIX.wrapper_module = self.scrtdir)

Definition at line 251 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py